@@ -1654,7 +1654,7 @@ void KCalculator::showSettings() {
 	connect(tmp_menu, SIGNAL(triggeredConstant(science_constant)), this, SLOT(slotChooseScientificConst5(science_constant)));
 	constants_->pushButton5->setMenu(tmp_menu);
 
-	dialog->addPage(constants_, i18n("Constants"), QLatin1String("preferences-kcalc-constants_"), i18n("Define Constants"));
+	dialog->addPage(constants_, i18n("Constants"), QLatin1String("preferences-kcalc-constants"), i18n("Define Constants"));
 
 	// When the user clicks OK or Apply we want to update our settings.
 	connect(dialog, SIGNAL(settingsChanged(QString)), SLOT(updateSettings()));
